//
//  DrixellasDilemma.h
//  DrixellasDilemma
//
//  Created by Vince Tagle on 8/26/04.
//  Copyright 2004 __MyCompanyName__. All rights reserved.
//

#import <Cocoa/Cocoa.h>
 
@class DrixellasView; 
@class NIRTimer;
@class DrixellasHighScore;
@class NextPieceView; 
@class BitmapGauge; 
@class Help;

@interface DrixellasDilemma : NSObject 
{
	IBOutlet NSWindow*				mainWindow;				//!< The main app window. 
	IBOutlet DrixellasView*			gameView;				//!< The NSView component displaying the game board. 
//	IBOutlet NSImageView*			nextPieceView;			//!< Displays the next piece for the player to place. 
	IBOutlet NSTextField*			numberOfTilesLeftField;	//!< Displays the number of tiles left the player has. 
	IBOutlet NSTextField*			scoreField;				//!< Displays the player's current score. 
	IBOutlet NSTextField*			errorMessageField;		//!< Displays the reason for the last invalid move. 
//	IBOutlet NSProgressIndicator*	tileTimeLeftIndicator;	//!< Displays the time left to play the current tile. 
	IBOutlet NSPanel*				gameStartSheet; 
	IBOutlet NSMenuItem*			practiceModeMenuItem; 
	IBOutlet NSMenuItem*			displayHintsMenuItem; 
	IBOutlet NSButton*				startGameButton; 
	IBOutlet NSButton*				endGameButton; 
	IBOutlet NSMenu*				tileSetMenu; 
	IBOutlet NextPieceView*			nextPieceView; 
	IBOutlet BitmapGauge*			tileTimeLeftIndicator; 
	IBOutlet NSPanel*				donationPanel;
	IBOutlet NSPanel*				gameFinishedPanel;
	
	NSTimer*	tileTimeLeftUpdater; 
	NSSound*	undoSound;
	BOOL		justStarted;
	BOOL		practiceMode; 
	BOOL		displayHints; 
	NSString*	extraTilesPath; 
	BOOL		donationSolicited; 
	
	DrixellasHighScore*	highScoresController; 
	Help*				helpController; 
}

- (IBAction)newGame: (id)sender; 
- (IBAction)endGame: (id)sender; 
- (IBAction)undoMove: (id)sender; 
- (IBAction)pauseGame: (id)sender; 
- (IBAction)startGame: (id)sender; 
- (IBAction)startPracticeGame: (id)sender; 
- (IBAction)setPracticeMode: (id)sender; 
- (IBAction)setDisplayHints: (id)sender; 
- (IBAction)displayHighScores: (id)sender; 
- (IBAction)setTileSet: (id)sender; 
- (IBAction)displayHelp: (id)sender; 
- (IBAction)dismissGameFinishedSheet: (id)sender; 
- (void)createNewGame; 
- (void)endCurrentGame;
- (void)noMovesLeft: (NSNotification *)notification; 
- (void)updateStatusDisplay: (NSImage *)nextPiece; 
- (void)updateTileTimeLeftDisplay;
- (void)displayErrorMessage: (SInt32)errorCode;
- (void)displayMessage: (NSString *)message; 
- (void)gameFinished; 
- (void)windowWillClose: (NSNotification *)aNotification;
- (void)fillMenu: (NSMenu *) menu usingPath: (NSString *)path withDefault: (NSString *)defaultChoice usingAction: (SEL)action;
- (void)updateHighScores;

/*!	\brief	Opens the website. 
*/
- (IBAction)openWebsite: (id)sender; 

/*!	\brief	Opens the donation page of the website. 
*/
- (IBAction)openDonationPage: (id)sender; 

/*!	\brief	Send an e-mail to me. 
*/
- (IBAction)sendEmail: (id)sender; 

/*!	\brief	Check for software updates. 
*/
- (IBAction)checkForUpdates: (id)sender; 

/*! \brief  Closes the donation solicitation sheet. 
*/
- (IBAction)closeDonationSheet: (id)sender; 

- (IBAction)validateLicenseFile: (id)sender; 
- (void)openLicenseFilePanelDidEnd: (NSOpenPanel *)panel returnCode: (int)returnCode contextInfo: (void  *)contextInfo;
- (NSString *)checkLicenseFile: (NSString *)licensePath;
- (NSString *)checkLicense: (NSData *)licenseData;

- (BOOL)application: (NSApplication *)theApplication openFile: (NSString *)filename;

@end
